Computes an approximate Bayesian credible interval for a semipartial
correlation with a skeptical prior. The skeptical prior distribution is
Normal with a mean of 0 and a small standard deviation. A skeptical prior
assumes that the population semipartial correlation is within a range of
small values (-r to r). If a skeptic is 95% confident that the population
correlation is between -r and r, then the prior standard deviation can be
set to r/1.96. A semipartial correlation that is less than .2 in absolute
value is typically considered to be "small", and the prior standard
deviation could then be set to .2/1.96. A semipartial correlation value
that is considered to be small will depend on the application. This function
requires the standard error of the estimated semipartial correlation which
can be obtained from the ci.spcor function.
For more details, see Section 2.36 of Bonett (2021, Volume 2)