Learn R Programming

statpsych (version 2.0.0)

ci.cor.dep: Confidence interval for a difference in dependent Pearson correlations

Description

Computes a confidence interval for a difference in population Pearson correlations that are estimated from the same sample and have one variable in common. A bias adjustment is used to reduce the bias of each Fisher transformed correlation. An approximate standard error is recovered from the confidence interval.

For more details, see Section 2.17 of Bonett (2021, Volume 2)

Usage

ci.cor.dep(alpha, cor1, cor2, cor12, n)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated correlation difference

  • SE - recovered standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

cor1

estimated Pearson correlation between y and x1

cor2

estimated Pearson correlation between y and x2

cor12

estimated Pearson correlation between x1 and x2

n

sample size

References

Zou2007statpsych

Bonett2021statpsych

Examples

Run this code
ci.cor.dep(.05, .396, .179, .088, 166)

# Should return:
# Estimate     SE     LL     UL
#    0.217 0.1027 0.0132 0.4158
 

Run the code above in your browser using DataLab