Learn R Programming

statpsych (version 2.0.0)

ci.cor2: Confidence interval for a 2-group Pearson correlation difference

Description

Computes a confidence interval for a difference in population Pearson correlations in a 2-group design. A bias adjustment is used to reduce the bias of each Fisher transformed correlation.

For more details, see Section 2.17 of Bonett (2021, Volume 2)

Usage

ci.cor2(alpha, cor1, cor2, n1, n2)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated correlation difference

  • SE - standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

cor1

estimated Pearson correlation for group 1

cor2

estimated Pearson correlation for group 2

n1

sample size for group 1

n2

sample size for group 2

References

Zou2007statpsych

Bonett2021statpsych

Examples

Run this code
ci.cor2(.05, .64, .31, 200, 200)

# Should return:
# Estimate      SE      LL     UL
#     0.33 0.07692  0.1797 0.4814
 

Run the code above in your browser using DataLab