Learn R Programming

statpsych (version 2.0.0)

ci.cronbach: Confidence interval for a Cronbach reliability

Description

Computes a confidence interval for a population Cronbach reliability. The point estimate of Cronbach reliability assumes essentially tau-equivalent measurements and the confidence interval assumes parallel measurements.

For more details, see Section 4.19 of Bonett (2021, Volume 1)

Usage

ci.cronbach(alpha, rel, r, n)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated Cronbach reliability (from input)

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

rel

estimated Cronbach reliability

r

number of measurements (items, raters, forms)

n

sample size

References

Feldt1965statpsych

Bonett2021statpsych

Examples

Run this code
ci.cronbach(.05, .85, 7, 89)

# Should return:
# Estimate       SE     LL     UL
#     0.85  0.02457 0.7971 0.8932
 

Run the code above in your browser using DataLab