Learn R Programming

statpsych (version 2.0.0)

ci.cronbach2: Confidence interval for a difference in Cronbach reliabilities in a 2-group design

Description

Computes a confidence interval for a difference in population Cronbach reliability coefficients in a 2-group design. The number of measurements (items, raters, forms) used in each group need not be equal.

For more details, see Section 2.15 of Bonett (2021, Volume 4)

Usage

ci.cronbach2(alpha, rel1, rel2, r1, r2, n1, n2)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated reliability difference

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

rel1

estimated Cronbach reliability for group 1

rel2

estimated Cronbach reliability for group 2

r1

number of measurements used in group 1

r2

number of measurements used in group 2

n1

sample size for group 1

n2

sample size for group 2

References

Bonett2021statpsych

Bonett2015statpsych

Examples

Run this code
ci.cronbach2(.05, .88, .76, 8, 8, 200, 250)

# Should return:
# Estimate     LL     UL
#     0.12 0.0697 0.1733
 

Run the code above in your browser using DataLab