ci.icc: Confidence interval for an intraclass reliability coefficient
Description
Computes a confidence interval for a population intraclass reliability
coefficient using mean squared estimates from a two-way ANOVA. This
function will compute point and interval estimates of the ICC(C, 1) and
ICC(C, r) reliability coefficients where ICC(C, 1) is the reliability of
a single measurements (e.g., a single rater or a single form of a test)
and ICC(C, r) is the reliability of a sum or average of r measurements.
ICC(C, r) is the same as Cronbach's reliability coefficient. The
ci.cronbach function uses a point estimate of Cronbach's reliability
as input. The confidence intervals used in this function assume parallel
measurements which implies a compound symmetric covariance matrix of
the r measurements.
Usage
ci.icc(alpha, MSr, MSe, r, n)
Value
Returns a 2-row matrix. The first row results are for ICC(C, 1) and
the second row results are for ICC(C, r). The columns are: