Learn R Programming

statpsych (version 2.0.0)

ci.poisson: Confidence interval for a Poisson rate

Description

Computes a confidence interval for a population Poisson rate. This function requires the number of occurrences (f) of a specific event that were observed over a specific period of time (t).

Usage

ci.poisson(alpha, f, t)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated Poisson rate

  • SE - recovered standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha value for 1-alpha confidence

f

number of event occurrences

t

time period

Details

The time period (t) does not need to be an integer and can be expressed in any unit of time such as seconds, hours, or months. The occurrences are assumed to be independent of one another and the unknown occurrence rate is assumed to be constant over time.

References

Hahn1991statpsych

Examples

Run this code
ci.poisson(.05, 23, 5.25)

# Should return:
# Estimate        SE       LL      UL
# 4.380952 0.9684952 2.777148 6.57358
 

Run the code above in your browser using DataLab