Learn R Programming

statpsych (version 2.0.0)

ci.reliability: Confidence interval for a reliability coefficient

Description

Computes a confidence interval for a population reliability coefficient such as Cronbach's alpha or McDonald's omega using an estimate of the reliability and its standard error. The standard error can be a robust standard error or bootstrap standard error obtained from an SEM program. Use ci.cronbach for Cronbach's alpha if parallel measurements can be assumed.

For more details, see Section 2.8 of Bonett (2021, Volume 4)

Usage

ci.reliability(alpha, rel, se, n)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated reliability (from input)

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

rel

estimated reliability

se

standard error of reliability

n

sample size

References

Bonett2021statpsych

Examples

Run this code
ci.reliability(.05, .88, .0147, 100)

# Should return:
# Estimate     LL     UL
#     0.88  0.849 0.9066
 

Run the code above in your browser using DataLab