Learn R Programming

statpsych (version 2.0.0)

ci.spcor: Confidence interval for a semipartial correlation

Description

Computes a Fisher confidence interval for a population semipartial correlation. This function requires an (unadjusted) estimate of the squared multiple correlation in the full model that contains the predictor variable of interest plus all control variables. This function computes a modified Aloe-Becker confidence interval that uses n - 3 rather than n in the standard error and also uses a Fisher transformation of the semipartial correlation.

For more details, see Section 2.7 of Bonett (2021, Volume 2)

Usage

ci.spcor(alpha, cor, r2, n)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated semipartial correlation (from input)

  • SE - standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

cor

estimated semipartial correlation

r2

estimated squared multiple correlation in full model

n

sample size

References

Bonett2021statpsych

Aloe2012statpsych

Examples

Run this code
ci.spcor(.05, -.355, .230, 236)

# Should return:
# Estimate      SE      LL      UL
#   -0.355 0.05426 -0.4565 -0.2444
 

Run the code above in your browser using DataLab