Learn R Programming

statpsych (version 2.0.0)

ci.var.upper: Upper confidence limit of a variance

Description

Computes an upper confidence limit for a population variance using an estimated variance from a sample of size n in a prior study. The upper limit can be used as a variance planning value in sample size functions for desired power that require a planning value of the population variance.

For more details, see Section 1.31 of Bonett (2021, Volume 1)

Usage

ci.var.upper(alpha, var, n)

Value

Returns an upper limit (UL) variance planning value

Arguments

alpha

alpha value for 1-alpha confidence (one-sided)

var

estimated variance

n

sample size

References

Bonett2021statpsych

Examples

Run this code
ci.var.upper(.10, 1.45, 100)

# Should return:
#       UL
# 1.762447
 

Run the code above in your browser using DataLab