Learn R Programming

statpsych (version 1.9.0)

iqv: Indices of qualitative variation

Description

Computes the Shannon, Berger, and Simpson indices of qualitative variation. Will be replaced soon with ci.diversity.

Usage

iqv(f)

Value

Returns estimates of the Shannon, Berger, and Simpson indices

Arguments

f

vector of multinomial frequency counts

Examples

Run this code
f <- c(10, 46, 15, 3)
iqv(f)

# Should return:
#   Simpson    Berger   Shannon
# 0.7367908 0.5045045       0.7
 

Run the code above in your browser using DataLab