Skip to contents

Computes the approximate power of a Mann-Whitney U test for a planned sample size. In a 2-group experiment, the effect size is the proportion of members in the population with scores that would be higher under treatment 1 than treatment 2. In a 2-group nonexperiment where participants are sampled from two subpopulations of sizes N1 and N2, the effect size is the proportion of all N1 x N2 pairs in which a member from subpopulation 1 has a larger score than a member from subpopulation 2.

Usage

power.mann(alpha, n1, n2, es)

Arguments

alpha

alpha level for hypothesis test

n1

planned sample size for group 1

n2

planned sample size for group 2

es

planning value of effect size (between .5 and 1)

Value

Returns the approximate power of the test

References

Noether GE (1987). “Sample size determination for some common nonparametric tests.” Journal of the American Statistical Association, 82(398), 645–647. ISSN 0162-1459, doi:10.1080/01621459.1987.10478478 .

Examples

power.mann(.05, 50, 50, .65)
#>   Power
#>  0.7383

# Should return:
#   Power
#  0.7383