Computes the sample size for each group required to estimate a mean difference in a 2-group ANCOVA model with desired confidence interval precision. In a nonexperimental design, the sample size is affected by the magnitude of covariate mean differences across groups. The covariate mean differences can be approximated by specifying the largest standardized covariate mean difference of all covariates. In an experiment, this standardized mean difference should be set to 0. Set the error variance planning value to the largest value within a plausible range for a conservatively large sample size. Note that the within-group error variance is equal to the within-group variance times 1 minus the the squared correlation (s = 1) or squared multiple correlation (s > 1) between the response variable and the covariate(s).
For more details, see Section 2.28 of Bonett (2021, Volume 2)