Learn R Programming

statpsych (version 2.0.0)

size.ci.cronbach: Sample size for a Cronbach reliability confidence interval

Description

Computes the sample size required to estimate a Cronbach reliability with desired confidence interval precision. Set the reliability planning value to the smallest value within a plausible range for a conservatively large sample size.

Usage

size.ci.cronbach(alpha, rel, r, w)

Value

Returns the required sample size

Arguments

alpha

alpha value for 1-alpha confidence

rel

reliability planning value

r

number of measurements (items, raters, forms)

w

desired confidence interval width

Details

For more details, see Section 4.26 of Bonett (2021, Volume 1)

References

Bonett2015statpsych

Bonett2021statpsych

Examples

Run this code
size.ci.cronbach(.05, .75, 5, .15)

# Should return:
# Sample size
#         109
 

Run the code above in your browser using DataLab