Learn R Programming

statpsych (version 2.0.0)

size.ci.kendalltau: Sample size for a Kendall-a correlation confidence interval

Description

Computes the sample size required to estimate a population Kendall tau-a correlation with desired confidence interval precision. Set the correlation planning value to the smallest absolute value within a plausible range for a conservatively large sample size.

Usage

size.ci.kendalltau(alpha, cor, w)

Value

Returns the required sample size

Arguments

alpha

alpha level for 1-alpha confidence

cor

planning value of correlation

w

desired confidence interval width

References

Bonett2000statpsych

Examples

Run this code
size.ci.kendalltau(.05, .3, .2)

# Should return:
# Sample size
#         143
 

Run the code above in your browser using DataLab