Learn R Programming

statpsych (version 2.0.0)

size.ci.pbcor: Sample size for a point-biserial correlation confidence interval

Description

Computes the sample size required to estimate a population point-biserial correlation with desired confidence interval precision in a two-group nonexperimental design with simple random sampling. A two-group nonexperimental design implies two subpopulations (e.g., all boys and all girls in a school district). This function requires a planning value for the proportion of population members who belong to one of the two subpopulations. Set the correlation planning value to the smallest absolute value within a plausible range for a conservatively large sample size.

For more details, see Section 1.24 of Bonett (2021, Volume 2)

Usage

size.ci.pbcor(alpha, cor, w, p)

Value

Returns the required sample size

Arguments

alpha

alpha level for 1-alpha confidence

cor

planning value of point-biserial correlation

w

desired confidence interval width

p

proportion of members in one of the two subpopulations

References

Bonett2020astatpsych

Bonett2021statpsych

Examples

Run this code
size.ci.pbcor(.05, .40, .25, .73)

# Should return:
# Sample size
#         168
 

Run the code above in your browser using DataLab