Computes the sample size required to perform an equivalence test for the
difference in population means with desired power in a paired-samples
design. The value of h specifies a range of practical equivalence, -h to h,
for the difference in population means. The planning value for the absolute
mean difference must be less than h. Equivalence tests often require a
very large sample size. Equivalence tests usually use 2 x alpha rather than
alpha (e.g., use alpha = .10 rather alpha = .05). Set the Pearson correlation
value to the smallest value within a plausible range, and set the variance
planning value to the largest value within a plausible range for a
conservatively large sample size.
For more details, see Section 4.27 of Bonett (2021, Volume 1)