Learn R Programming

statpsych (version 2.0.0)

test.prop.bs: Hypothesis test of equal proportions in a between-subjects design

Description

Computes a Pearson chi-square test for equal population proportions for a dichotomous response variable in a one-factor between-subjects design.

For more details, see Section 2.13 of Bonett (2021, Volume 3)

Usage

test.prop.bs(f, n)

Value

Returns a 1-row matrix. The columns are:

  • Chi-square - chi-square test statistic

  • df - degrees of freedom

  • p - p-value

Arguments

f

vector of frequency counts of participants who have the attribute

n

vector of sample sizes

References

Fleiss2003statpsych

Bonett2021statpsych

Examples

Run this code
f <- c(111, 118, 132)
n <- c(200, 200, 200)
test.prop.bs (f, n)

# Should return:
# Chi-square df       p
#     4.7706  2 0.09206


Run the code above in your browser using DataLab