Learn R Programming

statpsych (version 2.0.0)

ci.cramer: Confidence interval for Cramer's V

Description

Computes a confidence interval for a population Cramer's V coefficient of nominal association for an r x s contingency table. The confidence interval is based on a noncentral chi-square distribution, and an approximate standard error is recovered from the confidence interval.

For more details, see Section 3.10 of Bonett (2021, Volume 3)

Usage

ci.cramer(alpha, chisqr, r, c, n)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated Cramer's V

  • SE - recovered standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha value for 1-alpha confidence

chisqr

Pearson chi-square test statistic of independence

r

number of rows in contingency table

c

number of columns in contingency table

n

sample size

References

Smithson2003statpsych

Bonett2021statpsych

Examples

Run this code
ci.cramer(.05, 19.21, 2, 3, 200)

# Should return:
# Estimate     SE   LL    UL
#     0.31 0.0718 0.16 0.442
 

Run the code above in your browser using DataLab