powered by
Computes a confidence interval for a population mean using the estimated mean, estimated standard deviation, and sample size. Use the t.test function for raw data input.
For more details, see Section 1.7 of Bonett (2021, Volume 1)
ci.mean(alpha, m, sd, n)
Returns a 1-row matrix. The columns are:
Estimate - estimated mean
SE - standard error
LL - lower limit of the confidence interval
UL - upper limit of the confidence interval
alpha level for 1-alpha confidence
estimated mean
estimated standard deviation
sample size
Snedecor1980statpsych
Bonett2021statpsych
ci.mean(.05, 38.3, 8.14, 10) # Should return: # Estimate SE LL UL # 38.3 2.574094 32.47699 44.12301
Run the code above in your browser using DataLab