Learn R Programming

statpsych (version 2.0.0)

ci.rsqr: Confidence interval for squared multiple correlation

Description

Computes an approximate confidence interval for a population squared multiple correlation in a linear model with random predictor variables. This function uses the scaled central F approximation method. An approximate standard error is recovered from the confidence interval.

For more details, see Section 2.4 of Bonett (2021, Volume 2)

Usage

ci.rsqr(alpha, r2, s, n)

Value

Returns a 1-row matrix. The columns are:

  • R-squared - estimated unadjusted R-squared (from input)

  • adj R-squared - bias adjusted R-squared estimate

  • SE - recovered standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha value for 1-alpha confidence

r2

estimated unadjusted squared multiple correlation

s

number of predictor variables

n

sample size

References

Helland1987statpsych

Bonett2021statpsych

Examples

Run this code
ci.rsqr(.05, .247, 4, 150)

# Should return:
# R-squared adj R-squared      SE      LL     UL  
#     0.247        0.2262 0.06024  0.1152 0.3514
 

Run the code above in your browser using DataLab