ci.rsqr: Confidence interval for squared multiple correlation
Description
Computes an approximate confidence interval for a population squared
multiple correlation in a linear model with random predictor variables.
This function uses the scaled central F approximation method. An
approximate standard error is recovered from the confidence interval.
For more details, see Section 2.4 of Bonett (2021, Volume 2)