ci.sd: Confidence interval for a standard deviation
Description
Computes the traditional confidence interval for a population standard
deviation using a sample estimate of the standard deviation. The traditional
confidence interval assumes normality and is hypersensitive to minor
violations of this assumption. This function should be used only if the
data appear to come from an approximate normal or mildly platykurtic
distribution.
Usage
ci.sd(alpha, sd, n)
Value
Returns a 1-row matrix. The columns are:
Estimate - estimated standard deviation (from input)