Learn R Programming

statpsych (version 2.0.0)

ci.spear: Confidence interval for a Spearman correlation

Description

Computes a Fisher confidence interval for a population Spearman correlation. Unlike the confidence interval for a Pearson correlation, this function does not assume bivariate normality. Unlike the Pearson correlation which describes a linear bivariate relation, the Spearman correlation describes a monotonic bivariate relation. This function is not appropriate for ordered categorical variables.

For more details, see Section 1.32 of Bonett (2021, Volume 2)

Usage

ci.spear(alpha, y, x)

Value

Returns a 1-row matrix. The columns are:

  • Estimate - estimated Spearman correlation

  • SE - standard error

  • LL - lower limit of the confidence interval

  • UL - upper limit of the confidence interval

Arguments

alpha

alpha level for 1-alpha confidence

y

vector of y scores

x

vector of x scores (paired with y)

References

Bonett2000statpsych

Bonett2021statpsych

Examples

Run this code
y <- c(21, 4, 9, 12, 35, 18, 10, 22, 24, 1, 6, 8, 13, 16, 19)
x <- c(67, 28, 30, 28, 52, 40, 25, 37, 44, 10, 14, 20, 28, 40, 51)
ci.spear(.05, y, x)

# Should return:
# Estimate      SE     LL     UL
#     0.87 0.08241 0.5841 0.9638
 

Run the code above in your browser using DataLab