powered by
Computes the Shannon, Berger, and Simpson indices of qualitative variation. Will be replaced soon with ci.diversity.
iqv(f)
Returns estimates of the Shannon, Berger, and Simpson indices
vector of multinomial frequency counts
f <- c(10, 46, 15, 3) iqv(f) # Should return: # Simpson Berger Shannon # 0.7367908 0.5045045 0.7
Run the code above in your browser using DataLab