size.ci.sd: Sample size for a standard deviation confidence interval
Description
Computes the sample size required to estimate a population standard
deviation with desired confidence interval precision. This function
assumes that the traditional confidence interval for a population
standard deviation will be used. The traditional confidence interval
assumes that the response variable has an approximate normal
distribution and can be highly inaccurate when this assumption is not
satisfied.
Usage
size.ci.sd(alpha, r)
Value
Returns the required sample size
Arguments
alpha
alpha level for 1-alpha confidence
r
desired upper to lower confidence interval endpoint ratio