Learn R Programming

statpsych (version 2.0.0)

size.test.mann: Sample size for a Mann-Whitney test

Description

Computes the sample size in each group (assuming equal sample sizes) required for the Mann-Whitney test with desired power. A planning value of the Mann-Whitney parameter is required. In a 2-group experiment, this parameter is the proportion of members in the population with scores that would be larger under treatment 1 than treatment 2. In a 2-group nonexperiment where participants are sampled from two subpopulations of sizes N1 and N2, the parameter is the proportion of all N1 x N2 pairs in which a member from subpopulation 1 has a larger score than a member from subpopulation 2.

For more details, see Section 2.14 of Bonett (2021, Volume 1)

Usage

size.test.mann(alpha, pow, p)

Value

Returns the required sample size for each group

Arguments

alpha

alpha level for hypothesis test

pow

desired power

p

planning value of Mann-Whitney parameter

References

Noether1987statpsych

Bonett2021statpsych

Examples

Run this code
size.test.mann(.05, .90, .3)

# Should return:
# Sample size per group
#                    44
 

Run the code above in your browser using DataLab