test.kurtosis: Computes p-value for test of excess kurtosis
Description
Computes a Monte Carlo p-value (250,000 replications) for the null
hypothesis that the sample data come from a normal distribution. If the
p-value is small (e.g., less than .05) and excess kurtosis is positive,
then the normality assumption can be rejected due to leptokurtosis. If the
p-value is small (e.g., less than .05) and excess kurtosis is negative,
then the normality assumption can be rejected due to platykurtosis.
For more details, see Section 1.23 of Bonett (2021, Volume 1)
Usage
test.kurtosis(y)
Value
Returns a 1-row matrix. The columns are:
Kurtosis - estimate of kurtosis coefficient
Excess - estimate of excess kurtosis (kurtosis - 3)