Learn R Programming

statpsych (version 2.0.0)

test.kurtosis.geary: Computes estimate and test of excess Geary kurtosis

Description

Computes an estimate and test for kurtosis using a modfication of Geary's measure of kurtosis. If the p-value is small (e.g., less than .05) and excess kurtosis is positive, then the normality assumption can be rejected due to leptokurtosis. If the p-value is small (e.g., less than .05) and excess kurtosis is negative, then the normality assumption can be rejected due to platykurtosis. The estimate and test of Geary's kurtosis used here is based on a transformation of Geary's orginal measure of kurtosis proposed by Bonett and Seier (2002). Geary's kurtosis tends to be more sensitive to peakedness than Pearson's kurtosis, and Pearson's kurtosis tend to be more sensitive to tail weight than Geary's kurtosis. In the same way that it is informative to assess centrality and variability using more than one measure, it is also informative to assess kurtosis using both Pearson kurtosis and Geary kurtosis. See (see test.kurtosis) for a test of Pearson kurtosis.

Usage

test.kurtosis.geary(y)

Value

Returns a 1-row matrix. The columns are:

  • Kurtosis - estimate of transformed Geary kurtosis coefficient

  • Excess - estimate of excess kurtosis (kurtosis - 3)

  • z - z test statistic

  • p - two-sided p-value

Arguments

y

vector of quantitative scores

References

Bonett2002cstatpsych

Examples

Run this code
y <- c(58, 58, 55, 52, 20, 65, 59, 49, 51, 81, 40, 62, 56, 49, 49, 50, 44, 53, 59)
test.kurtosis.geary(y)

# Should return:
# Kurtosis Excess     z     p
#    5.157  2.157 2.793 0.005


Run the code above in your browser using DataLab