Computes a Monte Carlo p-value (250,000 replications) for the null
hypothesis that the sample data come from a normal distribution. If the
p-value is small (e.g., less than .05) and the skewness estimate is
positive, then the normality assumption can be rejected due to positive
skewness. If the p-value is small (e.g., less than .05) and the skewness
estimate is negative, then the normality assumption can be rejected due
to negative skewness.
For more details, see Section 1.23 of Bonett (2021, Volume 1)